@@ -1,5 +1,5 @@
 package Catalyst::ControllerRole::CatchErrors;
-$Catalyst::ControllerRole::CatchErrors::VERSION = '0.02';
+$Catalyst::ControllerRole::CatchErrors::VERSION = '0.03';
 use Moose::Role;
 
 requires qw/ catch_errors end /;
@@ -30,7 +30,7 @@ Catalyst::ControllerRole::CatchErrors - custom error handling in your controller
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -49,10 +49,11 @@ version 0.02
 If an action throws an error the default behaviour of L<Catalyst|Catalyst::Runtime>
 is to render a default error page and set the response code to 500.
 One usecase where this is problematic is if you have a REST Controller using
-L<Catalyst::Action::REST>. If you apply the C<Catalyst::ControllerRole::CatchErrors> role
-to your controller you can provide a C<catch_errors> action that receives an array of
-all errors that occurred during the request and do with them whatever you want.
-You can even rethrow the error. C<Catalyst::ControllerRole::CatchErrors> passes a copy of the errors
+L<Catalyst::Action::REST>. C<Catalyst::ControllerRole::CatchErrors> requires
+a C<catch_errors> action that receives an array of all errors that occurred
+during the request.
+
+You can rethrow the error in C<catch_errors>. C<Catalyst::ControllerRole::CatchErrors> passes a copy of the errors
 to your method and clears the original ones before calling C<catch_errors>.
 
 =head1 AUTHOR
